@@ -17,6 +17,11 @@ var annotated_dup =
     [ "jsLostStreamData", "structjs_lost_stream_data.html", "structjs_lost_stream_data" ],
     [ "jsMsgMetaData", "structjs_msg_meta_data.html", "structjs_msg_meta_data" ],
     [ "jsOptions", "structjs_options.html", "structjs_options" ],
+    [ "jsOptionsPublishAsync", "structjs_options_publish_async.html", "structjs_options_publish_async" ],
+    [ "jsOptionsPullSubscribeAsync", "structjs_options_pull_subscribe_async.html", "structjs_options_pull_subscribe_async" ],
+    [ "jsOptionsStream", "structjs_options_stream.html", "structjs_options_stream" ],
+    [ "jsOptionsStreamInfo", "structjs_options_stream_info.html", "structjs_options_stream_info" ],
+    [ "jsOptionsStreamPurge", "structjs_options_stream_purge.html", "structjs_options_stream_purge" ],
     [ "jsPeerInfo", "structjs_peer_info.html", "structjs_peer_info" ],
     [ "jsPlacement", "structjs_placement.html", "structjs_placement" ],
     [ "jsPubAck", "structjs_pub_ack.html", "structjs_pub_ack" ],
