@@ -1,10 +1,5 @@
 var nats_8h =
 [
-    [ "jsOptionsPublishAsync", "structjs_options_1_1js_options_publish_async.html", "structjs_options_1_1js_options_publish_async" ],
-    [ "jsOptionsPullSubscribeAsync", "structjs_options_1_1js_options_pull_subscribe_async.html", "structjs_options_1_1js_options_pull_subscribe_async" ],
-    [ "jsOptionsStream", "structjs_options_1_1js_options_stream.html", "structjs_options_1_1js_options_stream" ],
-    [ "jsOptionsStreamPurge", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge" ],
-    [ "jsOptionsStreamInfo", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_info" ],
     [ "NATS_EXTERN", "nats_8h.html#a3bc1b3fe7f64083e60c7c3b93f205bad", null ],
     [ "NATS_DEFAULT_URL", "nats_8h.html#a911c54900b46b968205871cd9f68d36c", null ],
     [ "JSMsgSize", "nats_8h.html#a5ce9005964bd9cf0604a9ef1afa87ea4", null ],
@@ -77,6 +72,11 @@ var nats_8h =
     [ "jsFetchRequest", "group__types_group.html#gaf11e6664c1f335a5287af71c703935fa", null ],
     [ "jsFetchCompleteHandler", "group__types_group.html#gaa17c5b961bcaa3c5907f48366b6e75c4", null ],
     [ "jsFetchNextHandler", "group__types_group.html#ga617d3ea9036a7ef05dd3868fa56abafc", null ],
+    [ "jsOptionsPullSubscribeAsync", "group__types_group.html#gab95e91e52f6ac008983ac46043f6d0ce", null ],
+    [ "jsOptionsPublishAsync", "group__types_group.html#gadce1d31b8609e6a5846e494b4709b038", null ],
+    [ "jsOptionsStreamPurge", "group__types_group.html#ga1211ad06fbed5ae556731234a84331f4", null ],
+    [ "jsOptionsStreamInfo", "group__types_group.html#ga7e9253d6a25dd87765cc43622058d0d8", null ],
+    [ "jsOptionsStream", "group__types_group.html#ga0801f894d749d82c62db8b21437cdf0e", null ],
     [ "jsOptions", "group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5", null ],
     [ "kvStore", "group__types_group.html#ga054c05493dd3cfc5c3e7a665a424e54a", null ],
     [ "kvEntry", "group__types_group.html#gad489fb4074f27427560ca71797db6191", null ],
@@ -101,7 +101,7 @@ var nats_8h =
     [ "natsEvLoop_Detach", "group__callbacks_group.html#gab63dee7f7012ba11ae20b76dbc36f2d0", null ],
     [ "natsUserJWTHandler", "group__callbacks_group.html#ga258b30458134be90f17315c037f34b7b", null ],
     [ "natsSignatureHandler", "group__callbacks_group.html#gab786ffd670c86de0563559351305080b", null ],
-    [ "natsTokenHandler", "group__callbacks_group.html#ga7d93a74068ac6e5f4406d70b7c1f0094", null ],
+    [ "natsTokenHandler", "group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499", null ],
     [ "natsOnCompleteCB", "group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a", null ],
     [ "natsCustomReconnectDelayHandler", "group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4", null ],
     [ "jsPubAckErrHandler", "group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992", null ],
@@ -123,7 +123,7 @@ var nats_8h =
     [ "microServiceConfig", "group__micro_types.html#ga1e46c0657cf42e83b366d224f380fb55", null ],
     [ "microServiceInfo", "group__micro_types.html#ga033705d0404de94efb7a6444c6e91743", null ],
     [ "microServiceStats", "group__micro_types.html#gaf832de937edc57bcc3af5e1456b3760c", null ],
-    [ "microRequestHandler", "group__micro_callbacks.html#ga95c185268f8eb44fa6ee16db4b33958e", null ],
+    [ "microRequestHandler", "group__micro_callbacks.html#gab465a9b31672c63738e8f6b0a61c2e90", null ],
     [ "microErrorHandler", "group__micro_callbacks.html#ga7a40fbbb9b1102f0a7679f9dfcf6c0d6", null ],
     [ "microDoneHandler", "group__micro_callbacks.html#gae0341a98388ffd1094472d2ced36d840", null ],
     [ "jsRetentionPolicy", "group__types_group.html#ga410f8fb053efa02b2ca1de0c02fa4b6d", [
@@ -166,15 +166,15 @@ var nats_8h =
       [ "kvOp_Delete", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a4efb91331f3307128c75af5b23362f83", null ],
       [ "kvOp_Purge", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332aee19ab8144bf518e251ea2004309b657", null ]
     ] ],
-    [ "nats_OpenWithConfig", "group__library_group.html#gac6a49d5ba110ce79c97792fbed584587", null ],
+    [ "nats_OpenWithConfig", "group__library_group.html#gab5e09f2429b8b790f030d8d91fbc20f4", null ],
     [ "nats_Open", "group__library_group.html#ga4a26d4caecb23348f6eee862c95fee7d", null ],
-    [ "nats_GetVersion", "group__library_group.html#gafc09930d38dcf3dcee144e8d3ffc225d", null ],
+    [ "nats_GetVersion", "group__library_group.html#ga0d8c3df1c0c4a3d340d8ff81355fb1e8", null ],
     [ "nats_GetVersionNumber", "group__library_group.html#ga5fbbaa19b0290b654d2669a05bd512e8", null ],
     [ "nats_CheckCompatibility", "group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e", null ],
     [ "nats_Now", "group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e", null ],
     [ "nats_NowInNanoSeconds", "group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223", null ],
     [ "nats_Sleep", "group__library_group.html#gad5040264cd4b1404956babf3c03a4f09", null ],
-    [ "nats_GetLastError", "group__library_group.html#ga2610d5691a89a0f2526989083bee0fd3", null ],
+    [ "nats_GetLastError", "group__library_group.html#gadecfd49a58b581dbba40da77b195fd85", null ],
     [ "nats_GetLastErrorStack", "group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e", null ],
     [ "nats_PrintLastErrorStack", "group__library_group.html#ga5fab3b18c4fe3630254483575f6066f4", null ],
     [ "nats_SetMessageDeliveryPoolSize", "group__library_group.html#gab21e94ce7a7d226611ea2c05914cf19d", null ],
@@ -182,7 +182,7 @@ var nats_8h =
     [ "nats_Sign", "group__library_group.html#gaf781f246e2e0ab24623ca667c48dc3ba", null ],
     [ "nats_Close", "group__library_group.html#gae75131e0ce4e5b89d0f82ea7892f112e", null ],
     [ "nats_CloseAndWait", "group__library_group.html#gaf75bb5b38bf32e6a8f43e54068625903", null ],
-    [ "natsStatus_GetText", "group__status_group.html#ga0f7a5e105311800d957ae7b28d1ab752", null ],
+    [ "natsStatus_GetText", "group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e", null ],
     [ "natsStatistics_Create", "group__stats_group.html#gafa923df029168f4991b77ffdd9e24877", null ],
     [ "natsStatistics_GetCounts", "group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f", null ],
     [ "natsStatistics_Destroy", "group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c", null ],
@@ -205,6 +205,7 @@ var nats_8h =
     [ "natsOptions_SetCipherSuites", "group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0", null ],
     [ "natsOptions_SetExpectedHostname", "group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851", null ],
     [ "natsOptions_SkipServerVerification", "group__opts_group.html#ga6f804ec44adc299989fe623570679da3", null ],
+    [ "natsOptions_SetSSLVerificationCallback", "group__opts_group.html#gaa2268dcf2f380b18ddb0e985a6ff7541", null ],
     [ "natsOptions_SetVerbose", "group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69", null ],
     [ "natsOptions_SetPedantic", "group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e", null ],
     [ "natsOptions_SetPingInterval", "group__opts_group.html#gae68fb615835364c0809555e8dc93f57e", null ],
@@ -268,9 +269,9 @@ var nats_8h =
     [ "natsInbox_Destroy", "group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe", null ],
     [ "natsMsgList_Destroy", "group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2", null ],
     [ "natsMsg_Create", "group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21", null ],
-    [ "natsMsg_GetSubject", "group__msg_group.html#gae4338b582ab420cf6d8373bef8cffd75", null ],
-    [ "natsMsg_GetReply", "group__msg_group.html#gaf3e9ab8edfa09b1e40ddb969d9ba5f01", null ],
-    [ "natsMsg_GetData", "group__msg_group.html#ga9b33d47bc5ff9fa987dea102b4a0498f", null ],
+    [ "natsMsg_GetSubject", "group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a", null ],
+    [ "natsMsg_GetReply", "group__msg_group.html#ga880535362c91b3e405792aa66ff945b6", null ],
+    [ "natsMsg_GetData", "group__msg_group.html#ga523364451fd92534e754054266196e59", null ],
     [ "natsMsg_GetDataLength", "group__msg_group.html#ga25b69066ae50287e178aaf4f70f7d3de", null ],
     [ "natsMsgHeader_Set", "group__msg_group.html#gaf30b47d4217c9335919f05536e379af8", null ],
     [ "natsMsgHeader_Add", "group__msg_group.html#ga2b641ec3b1745604d7de1102e472254b", null ],
@@ -283,12 +284,13 @@ var nats_8h =
     [ "stanMsg_GetSequence", "group__stan_msg_group.html#ga98b66ff73447e1d7e329edbfcde782b5", null ],
     [ "stanMsg_GetTimestamp", "group__stan_msg_group.html#ga2fa524b11e9621cf46ca9b1a3ca66452", null ],
     [ "stanMsg_IsRedelivered", "group__stan_msg_group.html#ga8e537d014b89d9d7da7906b2ee75d5c0", null ],
-    [ "stanMsg_GetData", "group__stan_msg_group.html#ga27477570a712b0d6315a823fc400b038", null ],
+    [ "stanMsg_GetData", "group__stan_msg_group.html#ga2f27fbfb79a46c52e079f670c59e1260", null ],
     [ "stanMsg_GetDataLength", "group__stan_msg_group.html#ga7d1e394a686bc25ab7376b7f28b9e777", null ],
     [ "stanMsg_Destroy", "group__stan_msg_group.html#gacd0059fb499963f5b2eae18053e5f74f", null ],
     [ "natsConnection_Connect", "group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce", null ],
-    [ "natsConnection_Reconnect", "group__conn_mgt_group.html#gab189a6974024f58944cdaa5612d4587e", null ],
+    [ "natsConnection_Reconnect", "group__conn_mgt_group.html#ga2f1151539f2d6c74d609274576da57bb", null ],
     [ "natsConnection_ProcessReadEvent", "group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8", null ],
+    [ "natsConnection_ProcessCloseEvent", "group__conn_mgt_group.html#ga9b0b13505d2dc85f49a5554c8a164876", null ],
     [ "natsConnection_ProcessWriteEvent", "group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47", null ],
     [ "natsConnection_ConnectTo", "group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4", null ],
     [ "natsConnection_IsClosed", "group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f", null ],
@@ -305,6 +307,7 @@ var nats_8h =
     [ "natsConnection_GetServers", "group__conn_mgt_group.html#gaf4ee7262e35e44c40ad5dfe9240db76b", null ],
     [ "natsConnection_GetDiscoveredServers", "group__conn_mgt_group.html#gad25c77be0873495412c90a73fe450708", null ],
     [ "natsConnection_GetLastError", "group__conn_mgt_group.html#gab6cfa9cb6857ae10f096a94f5e244e63", null ],
+    [ "natsConnection_ReadLastError", "group__conn_mgt_group.html#ga188adc519a5bd8f2ea674f78cdf90046", null ],
     [ "natsConnection_GetClientID", "group__conn_mgt_group.html#ga747513ba6ab63fdf9a72bfc8025a14ba", null ],
     [ "natsConnection_Drain", "group__conn_mgt_group.html#ga59bdc4ad9fea2053f5d3841f6b83f88b", null ],
     [ "natsConnection_DrainTimeout", "group__conn_mgt_group.html#gae06fe6f5933f216d6d93645a122a7dd4", null ],
@@ -335,7 +338,7 @@ var nats_8h =
     [ "natsSubscription_AutoUnsubscribe", "group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116", null ],
     [ "natsSubscription_QueuedMsgs", "group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254", null ],
     [ "natsSubscription_GetID", "group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20", null ],
-    [ "natsSubscription_GetSubject", "group__sub_group.html#ga0f65b49a355530c05445a3b9ce15cecb", null ],
+    [ "natsSubscription_GetSubject", "group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432", null ],
     [ "natsSubscription_SetPendingLimits", "group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4", null ],
     [ "natsSubscription_GetPendingLimits", "group__sub_group.html#ga786bb458981274fe717f266bd3b96d96", null ],
     [ "natsSubscription_GetPending", "group__sub_group.html#gaca6262e2ef842caa701a9f233db72707", null ],
@@ -438,11 +441,11 @@ var nats_8h =
     [ "js_KeyValue", "group__kv_group_mgt.html#ga54e6c109a7c633e431b3eded286e00f6", null ],
     [ "js_DeleteKeyValue", "group__kv_group_mgt.html#ga6bc715319560bc28359679fcdcead937", null ],
     [ "kvStore_Destroy", "group__kv_group_mgt.html#gab0d6bdbfabd27af67eaeb36cec0787da", null ],
-    [ "kvEntry_Bucket", "group__kv_entry.html#ga3671d74ba764a888c0c3f0df8d5c9dc0", null ],
-    [ "kvEntry_Key", "group__kv_entry.html#ga2d7c58132964d1d2861a30cc38b960aa", null ],
-    [ "kvEntry_Value", "group__kv_entry.html#ga82de8c62ea3ef6f8839169f922631176", null ],
+    [ "kvEntry_Bucket", "group__kv_entry.html#gadedbb410cce499afb535eb6641c32ca7", null ],
+    [ "kvEntry_Key", "group__kv_entry.html#gab455f32b0abfb1361dab4b5e7d98042a", null ],
+    [ "kvEntry_Value", "group__kv_entry.html#ga28077f81d71a30cbce2dc81e5c9574fc", null ],
     [ "kvEntry_ValueLen", "group__kv_entry.html#gaf7ccc866865903f231e0431754ed2415", null ],
-    [ "kvEntry_ValueString", "group__kv_entry.html#ga81060a449976b6801049763d4fe7339f", null ],
+    [ "kvEntry_ValueString", "group__kv_entry.html#ga7ff6220915726600545357e31226fb65", null ],
     [ "kvEntry_Revision", "group__kv_entry.html#ga2d58abf81cb577e21a76f9c77568409f", null ],
     [ "kvEntry_Created", "group__kv_entry.html#ga31ef3a2e3a7df6cf4dbb0a762737800a", null ],
     [ "kvEntry_Delta", "group__kv_entry.html#ga233a2d75895cfd0140cf77757592cf47", null ],
@@ -469,60 +472,60 @@ var nats_8h =
     [ "kvKeysList_Destroy", "group__kv_group.html#ga02ccd58bc5062f6ce6f94bf05e3dfe45", null ],
     [ "kvStore_History", "group__kv_group.html#ga5aa57345313cee85b020e50c22023fb5", null ],
     [ "kvEntryList_Destroy", "group__kv_group.html#gae783352ab81e22aa3173057d117518e6", null ],
-    [ "kvStore_Bucket", "group__kv_group.html#ga8fd5aa9d1c7af511650f60863a21ee84", null ],
+    [ "kvStore_Bucket", "group__kv_group.html#gad28fdf9aae16bba308cda799fca13281", null ],
     [ "kvStore_Status", "group__kv_group.html#gadf75e99cc28bc9c2d6eac7c9f7398c27", null ],
     [ "kvWatcher_Next", "group__kv_watcher.html#ga562c216a0199c30455af4c2da46000e5", null ],
     [ "kvWatcher_Stop", "group__kv_watcher.html#ga73adf44114fedd62ef75ebd81839b65e", null ],
     [ "kvWatcher_Destroy", "group__kv_watcher.html#ga21bc39fa795f7c4f392bd6d4e66ea1d9", null ],
-    [ "kvStatus_Bucket", "group__kv_status.html#ga9b81e3c0aa80b6165657cd68b687c156", null ],
+    [ "kvStatus_Bucket", "group__kv_status.html#ga1acec36db32207f21e15afc26bb5af1c", null ],
     [ "kvStatus_Values", "group__kv_status.html#ga2016af3c73841d8b226361e764dce158", null ],
     [ "kvStatus_History", "group__kv_status.html#gada6f22b5659b184762cea4f45d369ee5", null ],
     [ "kvStatus_TTL", "group__kv_status.html#gaa747ad0a6182ec7a47fb47018c33d1c1", null ],
     [ "kvStatus_Replicas", "group__kv_status.html#ga86b114f4dac9f06df86101f84bd497b2", null ],
     [ "kvStatus_Bytes", "group__kv_status.html#ga6db13a3b26c7c17633623da5f27978ff", null ],
     [ "kvStatus_Destroy", "group__kv_status.html#ga5eb3d824c1873af705beee4798246a08", null ],
-    [ "micro_AddService", "group__micro_service_functions.html#gab238a5c3d44f03a32bf2ecae62e11c19", null ],
-    [ "microService_AddEndpoint", "group__micro_service_functions.html#ga112ef90de06648f29330e191b5d613dc", null ],
-    [ "microService_AddGroup", "group__micro_service_functions.html#ga1e74f8d482ac32e9bcf29b0609d2ade6", null ],
-    [ "microService_Destroy", "group__micro_service_functions.html#gad7da17f143822a5caa57c90505453a6d", null ],
-    [ "microService_GetConnection", "group__micro_service_functions.html#ga348b4d33e070d9f9c991bd1165e45508", null ],
-    [ "microService_GetInfo", "group__micro_service_functions.html#ga715dc8b99716d691c37baa510697e9d6", null ],
-    [ "microService_GetState", "group__micro_service_functions.html#ga2eb6ef97d3939fee33e857227ef570ee", null ],
-    [ "microService_GetStats", "group__micro_service_functions.html#gaf59402d29dba31982e899415863a62d8", null ],
+    [ "micro_AddService", "group__micro_service_functions.html#ga2986a9751147b6f77064b5739635c2c1", null ],
+    [ "microService_AddEndpoint", "group__micro_service_functions.html#gadcab5687b72ec24ef7ae647ea844ebc7", null ],
+    [ "microService_AddGroup", "group__micro_service_functions.html#ga26c62ec5b8ed46e1503bb62d8b066d9c", null ],
+    [ "microService_Destroy", "group__micro_service_functions.html#ga32ff6b2fb38eafb4df8e6b1039ee5984", null ],
+    [ "microService_GetConnection", "group__micro_service_functions.html#ga20bb55e101c42a3b7172ea055b3ea04f", null ],
+    [ "microService_GetInfo", "group__micro_service_functions.html#gae7f5d4bde8ac12bde5ad48cebfad9e25", null ],
+    [ "microService_GetState", "group__micro_service_functions.html#gaf58eddc84ef124c80a86d380075ef226", null ],
+    [ "microService_GetStats", "group__micro_service_functions.html#ga19b3b7126a1e2472a4970fc16b2f9fb4", null ],
     [ "microService_IsStopped", "group__micro_service_functions.html#gac829b81893f09b1ed7c401147ed6b0c0", null ],
-    [ "microService_Run", "group__micro_service_functions.html#ga6a6a59f10e6764442bcac7fdd34b07d2", null ],
-    [ "microService_Stop", "group__micro_service_functions.html#ga3c54fa4faa6de985c411b08e62557d6e", null ],
-    [ "microGroup_AddGroup", "group__micro_group_functions.html#gaa18fb57d08b18a2927704acfc1343625", null ],
-    [ "microGroup_AddEndpoint", "group__micro_group_functions.html#ga4d9bc96f6e349296c2038126c931f027", null ],
-    [ "microRequest_AddHeader", "group__micro_request_functions.html#ga00363230b46c2794165c2dc10ca65fb5", null ],
-    [ "microRequest_DeleteHeader", "group__micro_request_functions.html#gaf3d72b449f4a72da06f3a7ce859a1ce9", null ],
-    [ "microRequest_GetConnection", "group__micro_request_functions.html#ga47f26882c6d2d9436f18fe75d2a17fa6", null ],
-    [ "microRequest_GetData", "group__micro_request_functions.html#ga4152732a49fc6401dc25bea5aa10b7fb", null ],
+    [ "microService_Run", "group__micro_service_functions.html#gaecde4e29e2b963e73fe4a8ff2fce064a", null ],
+    [ "microService_Stop", "group__micro_service_functions.html#ga35de7172dac67472ac3890bc955b9b42", null ],
+    [ "microGroup_AddGroup", "group__micro_group_functions.html#gade7fd0f2080a2e647b79c20a5019394d", null ],
+    [ "microGroup_AddEndpoint", "group__micro_group_functions.html#gabc9641ad7ee7775c388c864f2ffa6883", null ],
+    [ "microRequest_AddHeader", "group__micro_request_functions.html#ga6a6fa30291301abf54e25a24fde7e293", null ],
+    [ "microRequest_DeleteHeader", "group__micro_request_functions.html#gad50a68e2193da36d7b477a34f488840c", null ],
+    [ "microRequest_GetConnection", "group__micro_request_functions.html#ga6cf9c55a05fe1234ef264c25ca8294b3", null ],
+    [ "microRequest_GetData", "group__micro_request_functions.html#ga695cf95ff0f596affecbd3954fd498cf", null ],
     [ "microRequest_GetDataLength", "group__micro_request_functions.html#ga3fd1eef10afd445f517d73f32c9d4fd0", null ],
-    [ "microRequest_GetEndpointState", "group__micro_request_functions.html#gaf284671188c1d04a7488e20063b3ed54", null ],
-    [ "microRequest_GetHeaderKeys", "group__micro_request_functions.html#ga2089cf41f1b51e1cba8138bfd383433c", null ],
-    [ "microRequest_GetHeaderValue", "group__micro_request_functions.html#ga983d262fb2e77314af0f7bc0178306b9", null ],
-    [ "microRequest_GetHeaderValues", "group__micro_request_functions.html#gabb15bd720ee13fa8e489c8ae9ee52298", null ],
-    [ "microRequest_GetMsg", "group__micro_request_functions.html#ga7e27d518d856dbe040c17548d4757633", null ],
-    [ "microRequest_GetReply", "group__micro_request_functions.html#ga3adaed9594560b1d186b047277aa1163", null ],
-    [ "microRequest_GetService", "group__micro_request_functions.html#gaef03919ee49345f9eeb6b89c44936447", null ],
-    [ "microRequest_GetServiceState", "group__micro_request_functions.html#ga9925f42bbbf9831350a3065795631b0c", null ],
-    [ "microRequest_GetSubject", "group__micro_request_functions.html#ga4e8b8a731d62941fb46561538c04333e", null ],
-    [ "microRequest_Respond", "group__micro_request_functions.html#ga9f034636bf30623443b14542efd9a2f9", null ],
-    [ "microRequest_RespondError", "group__micro_request_functions.html#ga1967e15e58fefc2bef0403fec26b8463", null ],
-    [ "microRequest_RespondCustom", "group__micro_request_functions.html#ga0c7d26260030ce528aa8e0f9dbb0a643", null ],
-    [ "microRequest_SetHeader", "group__micro_request_functions.html#ga18a968ee89c6bd394397a3c140cd3c85", null ],
-    [ "micro_Errorf", "group__micro_error_functions.html#ga29eaa7704203b20e777ebf08f92152d8", null ],
-    [ "micro_ErrorfCode", "group__micro_error_functions.html#ga85d7590097c02c612f7d2e8a9fb46326", null ],
-    [ "micro_ErrorFromStatus", "group__micro_error_functions.html#ga1e4bf12e40b57a5d0a4cf43717771cf2", null ],
+    [ "microRequest_GetEndpointState", "group__micro_request_functions.html#gab999f2b9972c4339f6f78f491dfc6f3b", null ],
+    [ "microRequest_GetHeaderKeys", "group__micro_request_functions.html#gab78f9e653c13c8bbbbaa74d50dd34aa4", null ],
+    [ "microRequest_GetHeaderValue", "group__micro_request_functions.html#gad28fb0245a4c6d3218e4d233c141d3ce", null ],
+    [ "microRequest_GetHeaderValues", "group__micro_request_functions.html#gad73789e910856e6d3ece0ea95f1c8a54", null ],
+    [ "microRequest_GetMsg", "group__micro_request_functions.html#ga764c2ebab8816c4706d6e49e5cbe8320", null ],
+    [ "microRequest_GetReply", "group__micro_request_functions.html#gae87e12447ebc9864d38268a15c370182", null ],
+    [ "microRequest_GetService", "group__micro_request_functions.html#ga285974d2b6bc4b1369d9a9aa495e8119", null ],
+    [ "microRequest_GetServiceState", "group__micro_request_functions.html#ga8947795096eb225b16af422026627efa", null ],
+    [ "microRequest_GetSubject", "group__micro_request_functions.html#ga6727593cc380ad418e1d45d232ffea5e", null ],
+    [ "microRequest_Respond", "group__micro_request_functions.html#ga9c50e895154b151d3c9dadd3502b80f9", null ],
+    [ "microRequest_RespondError", "group__micro_request_functions.html#ga402e8ccd0602a27d333d50088f6a92a3", null ],
+    [ "microRequest_RespondCustom", "group__micro_request_functions.html#gae62bab929e8835da250870cfde2f22b2", null ],
+    [ "microRequest_SetHeader", "group__micro_request_functions.html#gab94d97619daf42590d7e6c6bd758b9ab", null ],
+    [ "micro_Errorf", "group__micro_error_functions.html#ga7732a5a63c3b452f8d78f4e41e726fe1", null ],
+    [ "micro_ErrorfCode", "group__micro_error_functions.html#ga91dd255ecb0fc97fddb0b8abe4a3fc4c", null ],
+    [ "micro_ErrorFromStatus", "group__micro_error_functions.html#gac557c5b7b565746d8c5521c726842641", null ],
     [ "microError_Code", "group__micro_error_functions.html#ga69edae8121c8a5a093c76ee2662bae54", null ],
     [ "microError_Destroy", "group__micro_error_functions.html#ga1bf0dc7e647ffd431bdca222d9246f07", null ],
     [ "microError_Status", "group__micro_error_functions.html#ga2648fe981670c5394bd058128ef6478c", null ],
-    [ "microError_String", "group__micro_error_functions.html#gaa4e5ef564e64393601f292abfc37e3ad", null ],
-    [ "microError_Wrapf", "group__micro_error_functions.html#ga3aa1ac805c27d3afc35c07fbe16c2d04", null ],
-    [ "micro_NewClient", "group__micro_client_functions.html#ga4d7d96defcccbc48e79b017629723e54", null ],
+    [ "microError_String", "group__micro_error_functions.html#ga9694838e69616612ef98afe7a45cb58d", null ],
+    [ "microError_Wrapf", "group__micro_error_functions.html#gad43118a9e9e48aefbde3b21c4bd9d36f", null ],
+    [ "micro_NewClient", "group__micro_client_functions.html#ga191be60c4f9bb88f83f73b5ce4e5e0bd", null ],
     [ "microClient_Destroy", "group__micro_client_functions.html#ga62a528edb67328bd7c478b6338656e1a", null ],
-    [ "microClient_DoRequest", "group__micro_client_functions.html#ga84cfeb41f87c0105f89e17ca37bc88a5", null ],
+    [ "microClient_DoRequest", "group__micro_client_functions.html#gac3be6a03f5846ac1bb06f091bea36a99", null ],
     [ "microServiceInfo_Destroy", "group__micro_cleanup_functions.html#ga9b4756ed693ce4fc0f06375aa0d3d54c", null ],
     [ "microServiceStats_Destroy", "group__micro_cleanup_functions.html#gaabcbf8378e6221eea78493a26576c8ce", null ],
     [ "micro_ErrorOutOfMemory", "group__micro_types.html#gab8c75a7c8001f647b5d2f27a0b26e82e", null ],
