@@ -2,6 +2,8 @@ var structmicro__endpoint__config__s =
 [
     [ "Name", "structmicro__endpoint__config__s.html#a1a47fe3be59a271217bcb4341cddecae", null ],
     [ "Subject", "structmicro__endpoint__config__s.html#a6c58e0e9c1da670da4a38993a613eb7d", null ],
+    [ "QueueGroup", "structmicro__endpoint__config__s.html#abf08a87593d4b7c3d1be7b7392f7fd67", null ],
+    [ "NoQueueGroup", "structmicro__endpoint__config__s.html#a920bf9f800a8b46227e4c52272e0c804", null ],
     [ "Metadata", "structmicro__endpoint__config__s.html#a7aee4ab9e29512c0b6ee12ba233c0fb7", null ],
     [ "Handler", "structmicro__endpoint__config__s.html#a4a916af910a5eb88abf3f0aa60082667", null ],
     [ "State", "structmicro__endpoint__config__s.html#ae9a1cf8dc159a651869e33c1f5cab3eb", null ]
