@@ -1,4 +1,4 @@
-// Copyright 2015-2022 The NATS Authors
+// Copyright 2015-2024 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -17,17 +17,18 @@
 #include "status.h"
 #include "gc.h"
 
-#define HDR_LINE_PRE        "NATS/1.0"
-#define HDR_LINE_PRE_LEN    (8)
-#define HDR_LINE            HDR_LINE_PRE _CRLF_
-#define HDR_LINE_LEN        (10)
-#define STATUS_HDR          "Status"
-#define DESCRIPTION_HDR     "Description"
-#define NO_RESP_STATUS      "503"
-#define NOT_FOUND_STATUS    "404"
-#define REQ_TIMEOUT         "408"
-#define CTRL_STATUS         "100"
-#define HDR_STATUS_LEN      (3)
+#define HDR_LINE_PRE                "NATS/1.0"
+#define HDR_LINE_PRE_LEN            (8)
+#define HDR_LINE                    HDR_LINE_PRE _CRLF_
+#define HDR_LINE_LEN                (10)
+#define STATUS_HDR                  "Status"
+#define DESCRIPTION_HDR             "Description"
+#define HDR_STATUS_NO_RESP_503      "503"
+#define HDR_STATUS_NOT_FOUND_404    "404"
+#define HDR_STATUS_TIMEOUT_408      "408"
+#define HDR_STATUS_MAX_BYTES_409    "409"
+#define HDR_STATUS_CTRL_100         "100"
+#define HDR_STATUS_LEN              (3)
 
 #define natsMsg_setNeedsLift(m)     ((m)->flags  |=  (1 << 0))
 #define natsMsg_needsLift(m)        (((m)->flags &   (1 << 0)) != 0)
@@ -40,6 +41,7 @@
 #define natsMsg_setNoDestroy(m)     ((m)->flags  |=  (1 << 2))
 #define natsMsg_isNoDestroy(m)      (((m)->flags &   (1 << 2)) != 0)
 #define natsMsg_clearNoDestroy(m)   ((m)->flags  &= ~(1 << 2))
+#define natsMsg_noDestroyFlag       (1 << 2)
 
 #define natsMsg_setTimeout(m)       ((m)->flags  |=  (1 << 3))
 #define natsMsg_isTimeout(m)        (((m)->flags &   (1 << 3)) != 0)
