@@ -187,7 +187,10 @@ typedef struct __natsSSLCtx
     SSL_CTX         *ctx;
     char            *expectedHostname;
     bool            skipVerify;
+
+#ifdef NATS_WITH_EXPERIMENTAL
     SSL_verify_cb   callback;
+#endif // NATS_WITH_EXPERIMENTAL
 
 } natsSSLCtx;
 
